@@ -10,7 +10,7 @@ use Carp();
 
 use base qw(Exporter);
 our @EXPORT_OK = qw(is_holiday holidays);
-our $VERSION   = '0.17';
+our $VERSION   = '0.18';
 
 my %cached;
 
@@ -461,16 +461,16 @@ my @days_in_month = ( 31, 0, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 )
 
 sub _compute_christmas_hash {
     my ( $year, $state ) = @_;
-    my ($day)   = 25;
-    my ($month) = 12;
-    my ($date) = Time::Local::timelocal( 0, 0, 0, $day, ( $month - 1 ), $year );
+    my $day   = 25;
+    my $month = 12;
+    my $date  = Time::Local::timelocal( 0, 0, 0, $day, ( $month - 1 ), $year );
     my ( $sec, $min, $hour, undef, undef, undef, $wday, $yday, $isdst ) =
       localtime $date;
-    my ($boxing_day) = 'Boxing Day';
+    my $boxing_day = 'Boxing Day';
     if ( $state eq 'SA' ) {
         $boxing_day = 'Proclamation Day';
     }
-    my (@holidays);
+    my @holidays;
     push @holidays,
       {
         'name' => 'Christmas Day',
@@ -555,7 +555,7 @@ sub _compute_nt_show_day_hash {
     );
     my ( $month, $num_fridays, $name );
     if ( ( exists $params->{region} ) && ( defined $params->{region} ) ) {
-        my ($region) = lc $params->{region};
+        my $region = lc $params->{region};
         $region =~ s/\s*//smxg;
         if ( $nt_show_day{$region} ) {
             $name        = $nt_show_day{$region}{name};
@@ -604,7 +604,7 @@ sub _compute_qld_show_day
     my $date = Time::Local::timelocal( 0, 0, 0, $day, $month, $year );
     my $wednesdays = 0;
     my ( $sec, $min, $hour, $wday, $yday, $isdst );
-    my ($num_wednesdays);
+    my $num_wednesdays;
     ( $sec, $min, $hour, undef, undef, undef, $wday, $yday, $isdst ) =
       localtime $date;
 
@@ -1212,7 +1212,7 @@ sub _compute_easter {
     if ( $wday != 0 ) {
         Carp::croak('Easter must fall on a Sunday');
     }
-    my (@holidays);
+    my @holidays;
 
     # good friday + easter saturday
     if ( $month == 2 ) {    # march
@@ -1279,7 +1279,7 @@ sub _compute {
     my ( $day, $month, $year, $params ) = @_;
     my $date = Time::Local::timelocal( 0, 0, 0, $day, ( $month - 1 ), $year );
     my ( $sec, $min, $hour, $wday, $yday, $isdst );
-    my (@holidays);
+    my @holidays;
     push @holidays, sprintf '%02d%02d', $month, $day;
     if ( $params->{day_in_lieu} ) {
         ( $sec, $min, $hour, $day, $month, $year, $wday, $yday, $isdst ) =
@@ -1343,7 +1343,7 @@ Date::Holidays::AU - Determine Australian Public Holidays
 
 =head1 VERSION
  
-Version 0.17
+Version 0.18
 
 =head1 SYNOPSIS
 
